#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const express_1 = __importDefault(require("express"));
const express_handlebars_1 = __importDefault(require("express-handlebars"));
const path_1 = __importDefault(require("path"));
const yargs_1 = __importDefault(require("yargs"));
const helpers_1 = require("yargs/helpers");
const git_utils_1 = require("./git-utils");
const branches_1 = require("./routes/branches");
const branch_1 = require("./routes/branch");
async function main() {
    const argv = await yargs_1.default(helpers_1.hideBin(process.argv))
        .scriptName('git-vis')
        .usage('Usage: $0 [args]')
        .example('$0 -d ./my-project -p 3000', 'runs git-vis on a specific directory and port')
        .option('d', {
        alias: 'directory',
        type: 'string',
        describe: 'a directory that contains a .git subdirectory - defaults to process.cwd()',
        nargs: 1,
        default: process.cwd(),
    })
        .option('p', {
        alias: 'port',
        type: 'number',
        describe: 'the port to run the web server',
        nargs: 1,
        default: 8080,
    })
        .help('h')
        .alias('h', 'help').argv;
    const app = express_1.default();
    const repo = await git_utils_1.getRepository(argv.d);
    const viewInstance = express_handlebars_1.default.create({
        extname: 'hbs',
        partialsDir: path_1.default.join(__dirname, 'views/partials'),
        helpers: {
            encodeURIComponent,
        },
    });
    app.engine('hbs', viewInstance.engine);
    app.set('views', __dirname + '/views');
    app.set('view engine', 'hbs');
    app.set('view-instance', viewInstance);
    app.set('repo', repo);
    app.set('directory', argv.d);
    app.use(express_1.default.static(path_1.default.resolve(__dirname, '../public')));
    app.get('/', function (req, res) {
        res.render('index');
    });
    app.use(branches_1.branchesRouter);
    app.use(branch_1.branchRouter);
    app.listen(argv.p, () => console.log(`Listening on port ${argv.p}...`));
}
main();
