"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.commitToCommitSummary = exports.branchToBranchSummary = exports.getBranchCommits = exports.getLocalBranches = exports.getBranch = exports.getRepository = void 0;
const nodegit_1 = __importDefault(require("nodegit"));
async function getRepository(path) {
    return await nodegit_1.default.Repository.open(path);
}
exports.getRepository = getRepository;
async function getBranch(repo, branchName) {
    return await repo.getReference(branchName);
}
exports.getBranch = getBranch;
async function getLocalBranches(repo) {
    const references = await repo.getReferences();
    return references.filter((reference) => reference.isBranch());
}
exports.getLocalBranches = getLocalBranches;
async function getRemoteBranches(repo) {
    const references = await repo.getReferences();
    return references.filter((reference) => reference.isRemote());
}
async function getBranchCommits(repo, branch) {
    const walker = repo.createRevWalk();
    walker.push(branch.target());
    return await walker.getCommits(100);
}
exports.getBranchCommits = getBranchCommits;
function branchToBranchSummary(branch) {
    return {
        name: branch.name().replace('refs/heads/', ''),
        isHead: branch.isHead(),
    };
}
exports.branchToBranchSummary = branchToBranchSummary;
function commitToCommitSummary(commit) {
    const message = commit.message();
    const messageSummary = message.length > 80 ? message.substring(0, 77) + '...' : message;
    return {
        sha: commit.sha().substring(0, 7),
        message: messageSummary,
    };
}
exports.commitToCommitSummary = commitToCommitSummary;
