"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.branchRouter = void 0;
const path_1 = __importDefault(require("path"));
const express_1 = require("express");
const chokidar_1 = __importDefault(require("chokidar"));
const git_utils_1 = require("../git-utils");
const branchRouter = express_1.Router();
exports.branchRouter = branchRouter;
branchRouter.get('/branch/:name', async (req, res) => {
    try {
        const branchName = req.params.name;
        const repo = req.app.get('repo');
        const branch = await git_utils_1.getBranch(repo, branchName);
        const commits = await git_utils_1.getBranchCommits(repo, branch);
        const commitSummaries = commits.map(git_utils_1.commitToCommitSummary);
        res.render('branch', {
            name: branchName,
            isHead: branch.isHead(),
            commits: commitSummaries,
        });
    }
    catch (e) {
        res.status(404).send(e.message);
    }
});
branchRouter.get('/branch/sse/:name', async (req, res) => {
    const branchName = req.params.name;
    const repo = req.app.get('repo');
    const directory = req.app.get('directory');
    const viewInstance = req.app.get('view-instance');
    const branchPath = `${directory}/.git/refs/heads/${branchName}`;
    const headPath = `${directory}/.git/HEAD`;
    console.log(`connected to /branches/see/${branchName}`);
    res.set({
        'Cache-Control': 'no-cache',
        'Content-Type': 'text/event-stream',
        Connection: 'keep-alive',
    });
    res.flushHeaders();
    // Tell the client to retry every 10 seconds if connectivity is lost
    res.write('retry: 10000\n\n');
    const watcher = chokidar_1.default.watch([branchPath, headPath], {
        ignoreInitial: true,
    });
    watcher.on('all', async (event) => {
        console.log(`${branchPath} change detected of type ${event}`);
        if (event === 'unlink') {
            const template = await viewInstance.render(path_1.default.join(__dirname, '../views/branch-reset-sse.hbs'), {});
            const line = template.replace(/\n/g, '');
            res.write(`data: ${line}\n\n`);
        }
        else {
            try {
                const branch = await git_utils_1.getBranch(repo, branchName);
                const commits = await git_utils_1.getBranchCommits(repo, branch);
                const commitSummaries = commits.map(git_utils_1.commitToCommitSummary);
                const template = await viewInstance.render(path_1.default.join(__dirname, '../views/branch-sse.hbs'), {
                    name: branchName,
                    isHead: branch.isHead(),
                    commits: commitSummaries,
                });
                const line = template.replace(/\n/g, '');
                res.write(`data: ${line}\n\n`);
            }
            catch (e) {
                console.error(e.message);
            }
        }
    });
    console.log(`watching for changes in ${branchPath}`);
    res.on('close', () => {
        console.log(`disconnected from /branches/see/${branchName}`);
        watcher.close().then(() => console.log(`${branchPath} watcher closed`));
    });
});
