"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.branchesRouter = void 0;
const path_1 = __importDefault(require("path"));
const express_1 = require("express");
const chokidar_1 = __importDefault(require("chokidar"));
const git_utils_1 = require("../git-utils");
const branchesRouter = express_1.Router();
exports.branchesRouter = branchesRouter;
branchesRouter.get('/branches', async (req, res) => {
    const repo = req.app.get('repo');
    const branches = await git_utils_1.getLocalBranches(repo);
    const branchSummaries = branches.map(git_utils_1.branchToBranchSummary);
    res.render('branches', { branches: branchSummaries });
});
branchesRouter.get('/branches/sse', async (req, res) => {
    const repo = req.app.get('repo');
    const directory = req.app.get('directory');
    const viewInstance = req.app.get('view-instance');
    const branchesPath = `${directory}/.git/refs/heads`;
    const headPath = `${directory}/.git/HEAD`;
    console.log('connected to /branches/see');
    res.set({
        'Cache-Control': 'no-cache',
        'Content-Type': 'text/event-stream',
        Connection: 'keep-alive',
    });
    res.flushHeaders();
    // Tell the client to retry every 10 seconds if connectivity is lost
    res.write('retry: 10000\n\n');
    const watcher = chokidar_1.default.watch([branchesPath, headPath], {
        ignoreInitial: true,
    });
    watcher.on('all', async () => {
        console.log(`${branchesPath} change detected`);
        try {
            const branches = await git_utils_1.getLocalBranches(repo);
            const branchSummaries = branches.map(git_utils_1.branchToBranchSummary);
            const template = await viewInstance.render(path_1.default.join(__dirname, '../views/branches-sse.hbs'), { branches: branchSummaries });
            const line = template.replace(/\n/g, '');
            res.write(`data: ${line}\n\n`);
        }
        catch (e) {
            console.error(e.message);
        }
    });
    console.log(`watching for changes in ${branchesPath}`);
    res.on('close', () => {
        console.log('disconnected from /branches/see');
        watcher.close().then(() => {
            console.log(`${branchesPath} watcher closed`);
        });
    });
});
